#!/usr/bin/env python3
#-*- coding: utf-8 -*-
from tkinter import *
from tkinter.messagebox import *

import sys

from pfc_joueur import *

# classe de base pour l'interface graphique
class Pfc_GUI :

    # constructeur: met l'historique à 0, crée les joueurs
    def __init__(self):
        self.history=''
        self.ordi = IAPfc()
        self.humain = Human()
        self.build_gui()
        self.maxcoups=int(self.objectif.get())
        self.gameover=False
        

    # methode pour démarrer une nouvelle partie
    def new(self):
        self.gameover=False
        self.history=''
        self.ordi.score = 0
        self.humain.score = 0
        self.objectif.configure(state=NORMAL)
        self.maxcoups=int(self.objectif.get())
        self.canvas.itemconfigure(self.scoretxt,text='0:0')
        self.canvas.itemconfigure(self.msg,text='quand tu veux')

    # methode pour cacher les mains
    def cacher_mains(self):
        for item in self.canvas.find_withtag('play') :
            self.canvas.itemconfigure(item,state=HIDDEN)

    # methode déterminant qui a gagné le coup
    def coup_gagnant(self,c1,c2):
        if c1=='P' :
            if c2=='P' : return 0
            if c2=='F' : return -1
            if c2=='C' : return 1
        if c1=='F':
            if c2=='P' : return 1
            if c2=='F' : return 0
            if c2=='C' : return -1
        if c1=='C':
            if c2=='P': return -1
            if c2=='F' : return 1
            if c2=='C' : return 0

    # methode saisissant le coup humain
    def click(self,event):
        if self.gameover : return
        self.maxcoups=int(self.objectif.get())
        self.objectif.configure(state=DISABLED)
        if self.canvas.find_withtag(CURRENT):
            tags=self.canvas.gettags(CURRENT)
            if tags[0] not in ['P','F','C'] : return
            coupO = self.ordi.coup_ia(self.history)
            coupH = tags[0]
            self.cacher_mains()
            
            #affichage des mains
            if coupH == 'P' : self.canvas.itemconfigure(self.jeuHP, state=NORMAL)
            if coupH == 'F' : self.canvas.itemconfigure(self.jeuHF, state=NORMAL)
            if coupH == 'C' : self.canvas.itemconfigure(self.jeuHC, state=NORMAL)
            if coupO == 'P' : self.canvas.itemconfigure(self.jeuOP, state=NORMAL)
            if coupO == 'F' : self.canvas.itemconfigure(self.jeuOF, state=NORMAL)
            if coupO == 'C' : self.canvas.itemconfigure(self.jeuOC, state=NORMAL)
            # maj historique
            self.history += coupO
            self.history += coupH.lower()
            # determine les coups gagnants + messages
            resultat = self.coup_gagnant(coupO,coupH)
            if resultat == 0:
                self.canvas.itemconfigure(self.msg,text='coup nul')
            elif resultat == 1:
                self.ordi.marque()
                self.canvas.itemconfigure(self.msg,text='niark niark')
            else :
                self.humain.marque()
                self.canvas.itemconfigure(self.msg,text='argggghhh !!')
            message = ''+str(self.humain.score)+':'+str(self.ordi.score)
            self.canvas.itemconfigure(self.scoretxt,text=message)

            # detecter la victoire
            if self.ordi.score >= self.maxcoups :
                self.gameover=True
                message="J'ai gagné!!!"
            if self.humain.score >= self.maxcoups :
                self.gameover=True
                message="Bravo!!!"
            if self.gameover :
                self.canvas.itemconfigure(self.msg,text=message)
            

    # construction de l'interface
    def build_gui(self):
        # fenetre principale et son canevas
        self.fenetre = Tk()
        self.canvas = Canvas( self.fenetre,width=550, height=320,bg='lightgreen' )

        # chargement des images
        self.photoHP = PhotoImage( file = "pierreH_1.png")
        self.photoHF = PhotoImage( file = "feuilleH_1.png")
        self.photoHC = PhotoImage( file = "ciseauxH_1.png")

        self.photoJeuHP = PhotoImage( file = "pierreH.png")
        self.photoJeuHF = PhotoImage( file = "feuilleH.png")
        self.photoJeuHC = PhotoImage( file = "ciseauxH.png")

        self.photoJeuOP = PhotoImage( file = "pierreO.png")
        self.photoJeuOF = PhotoImage( file = "feuilleO.png")
        self.photoJeuOC = PhotoImage( file = "ciseauxO.png")

        # placement des images
        self.choixHP = self.canvas.create_image(20,20,anchor=NW,image=self.photoHP,tags='P')
        self.choixHF = self.canvas.create_image(20,120,anchor=NW,image=self.photoHF,tags='F')
        self.choixHC = self.canvas.create_image(20,220,anchor=NW,image=self.photoHC,tags='C')

        self.jeuHP = self.canvas.create_image(180,75,anchor=NW,image=self.photoJeuHP,state=HIDDEN,tags= ('play','playH','P'))
        self.jeuHF = self.canvas.create_image(180,75,anchor=NW,image=self.photoJeuHF,state=HIDDEN,tags=('play','playH','F'))
        self.jeuHC = self.canvas.create_image(180,75,anchor=NW,image=self.photoJeuHC,state=HIDDEN,tags=('play','playH','C'))

        self.jeuOP = self.canvas.create_image(350,75,anchor=NW,image=self.photoJeuOP,state=HIDDEN,tags=('play','playO','P'))
        self.jeuOF = self.canvas.create_image(350,75,anchor=NW,image=self.photoJeuOF,state=HIDDEN,tags=('play','playO','F'))
        self.jeuOC = self.canvas.create_image(350,75,anchor=NW,image=self.photoJeuOC,state=HIDDEN,tags=('play','playO','C'))

        # les scores et le message
        self.scoretxt = self.canvas.create_text(250,15,anchor=NW,text='0:0',font=('Courier', '32'),fill='red')
        self.msg = self.canvas.create_text(250,5,anchor=NW,text='quand tu veux')

        # on place le canvas et on lui demande de détecter le click
        self.canvas.pack(side=LEFT)
        self.canvas.bind('<Button-1>',self.click)

        # les boutons à droite
        self.button1=Button(self.fenetre, text ='Niou',command=self.new)
        self.button1.pack(side=TOP, padx=5, pady=5)

        self.blabla = Label(self.fenetre, text = 'partie en :')
        self.blabla.pack(side=TOP, padx=5, pady=5)

        self.objectif = Spinbox(self.fenetre,from_=10, to=50)
        self.objectif.pack(side=TOP, padx=5, pady=5)

        self.button4=Button(self.fenetre, text= 'baille',command=self.fenetre.destroy)
        self.button4.pack(side=BOTTOM, padx=5, pady=5)


game=Pfc_GUI()
game.fenetre.mainloop()
